# biosiglive
`biosiglive` is a python library dedicated to streaming and processing biosignals in real time from Nexus or Delsys Trigno Community.
Please have a look to the documentation for more information about [biosiglive](https://biosiglive.readthedocs.io/en/latest/index.html). 

# Table of Contents  
[Testing bioptim](#try-bioptim)

[How to install](#how-to-install)
- [From anaconda](#installing-from-anaconda)
- [From pip](#installing-from-pip)
- [From the sources](#installing-from-the-sources)

[`biosiglive` API](#biosiglive-api)
- [GUI](#gui)
- [Interfaces](#interfaces)
- [File I/O](#io)
- [Processing](#processing)
- [Streaming](#streaming)

[Examples](#examples)

[Citing](#Citing)

# How to install
Biosiglive can be installed from anaconda, pip or from the sources.
Please refer to the [documentation](https://biosiglive.readthedocs.io/en/latest/install.html) to install biosiglive 

# `biosiglive` API
Several modules are implemented in biosiglive to allow versatile use. Please refer to the [documentation](https://biosiglive.readthedocs.io/en/latest/APIDocumentation.html) for more information. 
You can also look at the [example](https://biosiglive.readthedocs.io/en/latest/examples.html) to have a better overview of how to use biosiglive. 

## Examples
A set of example is provided in the `examples` folder. Please take a look at the [documentation example page](https://biosiglive.readthedocs.io/en/latest/examples.html) for description of each example.

## How to contribute
You are welcome to contribute to this project by following the steps describes in the 
[how to contribute](https://biosiglive.readthedocs.io/en/latest/contributing.html) page.

## How to cite
If you are using the biosig live library please cite us by following the guidelines available [here](https://biosiglive.readthedocs.io/en/latest/cite.html).










